last-day, last-week or last-month.
If this is given, then from and to are ignored.
from
Start date, in yyyy-mm-dd format, or
last-day. It is ignored if when is given.
to
End date, in yyyy-mm-dd format, or
last-day. It is ignored if when is given.
removeupdatespikes
Default TRUE. Removes the spike in downloads due to automatic re-downloads
and CRAN mirrors associated with a package update. Replaces value with the median download value across the measurement period.
numbercomparison
Default 100. The number of random packages to inspect to determine the minimum number of downloads in any single day.
packagequantile
Default 0.05. The quantile defining the "minimum" number of downloads on a single day.
Value
A data frame of downloads and total downloads by package.
date
Day of the downloads, it is a Date object.
package
The package. This column is missing if
all packages were queried.
count
Raw download count.
total_downloads
Raw total number of downloads from beginning of measurement period.
mindownloads
Estimated CRAN-wide automated downloads for that day.
updateday
TRUE if the package was updated that day, FALSE otherwise.
adjusted_downloads
Daily download count, adjusted.
adjusted_total_downloads
Adjusted total number of downloads from beginning of measurement period.
# NOT RUN {# }# NOT RUN {adj_cran_downloads("skpr",from="2017-08-15",to="2017-11-15")
adj_cran_downloads("skpr",when="last-month")
adj_cran_downloads(c("skpr","AlgDesign"),when="last-month")
# }